@@ -6,7 +6,19 @@ plot(params_BM(p = 2),
      data = monkeys$dat, phylo = monkeys$phy,
      show.tip.label = TRUE, cex = 0.5, no.margin = TRUE)
 
-## ---- label="Fit_EM", warning=FALSE, message=FALSE----------------------------
+## ---- label="Fit_EM", warning=FALSE, message=FALSE, eval=FALSE----------------
+#  res <- PhyloEM(phylo = monkeys$phy,
+#                 Y_data = monkeys$dat,
+#                 process = "scOU",                   ## scalar OU model
+#                 random.root = TRUE,                 ## Root is stationary
+#                 stationary.root = TRUE,
+#                 nbr_alpha = 4,                      ## Number of alpha values tested (should be raised)
+#                 K_max = 10,                         ## Maximal number of shifts
+#                 parallel_alpha = TRUE,              ## This can be set to TRUE for
+#                 Ncores = 2)                         ## parallel computations
+#  res
+
+## ----label="Fit_EM_int", echo=FALSE, warning=FALSE, message=FALSE-------------
 res <- PhyloEM(phylo = monkeys$phy,
                Y_data = monkeys$dat,
                process = "scOU",                   ## scalar OU model
@@ -14,8 +26,7 @@ res <- PhyloEM(phylo = monkeys$phy,
                stationary.root = TRUE,
                nbr_alpha = 4,                      ## Number of alpha values tested (should be raised)
                K_max = 10,                         ## Maximal number of shifts
-               parallel_alpha = TRUE,              ## This can be set to TRUE for
-               Ncores = 2)                         ## parallel computations
+               parallel_alpha = FALSE)              ## This can be set to TRUE for
 res
 
 ## ---- fig.show='hold', fig.height=4, fig.width=7, warning=FALSE---------------
@@ -34,7 +45,28 @@ params_5 <- params_process(res, K = 5)
 plot(equivalent_shifts(monkeys$phy, params_process(res, K = 5)),
      show_shifts_values = FALSE, shifts_cex = 0.5)
 
-## ---- label="Fit_EM_rot", warning=FALSE, message=FALSE------------------------
+## ---- label="Fit_EM_rot", warning=FALSE, message=FALSE, eval = FALSE----------
+#  # An arbitrary rotation
+#  theta <- pi/4
+#  rot <- matrix(c(cos(theta), -sin(theta), sin(theta), cos(theta)),
+#                nrow = 2, ncol = 2)
+#  
+#  # Rotate data
+#  Yrot <- t(rot) %*% monkeys$dat
+#  rownames(Yrot) <- rownames(monkeys$dat)
+#  
+#  # PhyloEM on rotated data
+#  res_rot <- PhyloEM(phylo = monkeys$phy,
+#                     Y_data = Yrot,                      ## rotated data
+#                     process = "scOU",
+#                     random.root = TRUE,
+#                     stationary.root = TRUE,
+#                     nbr_alpha = 4,
+#                     K_max = 10,
+#                     parallel_alpha = TRUE,
+#                     Ncores = 2)
+
+## ----label="Fit_EM_rot_int", echo=FALSE, warning=FALSE, message=FALSE---------
 # An arbitrary rotation
 theta <- pi/4
 rot <- matrix(c(cos(theta), -sin(theta), sin(theta), cos(theta)),
@@ -52,8 +84,7 @@ res_rot <- PhyloEM(phylo = monkeys$phy,
                    stationary.root = TRUE,
                    nbr_alpha = 4,
                    K_max = 10,                         
-                   parallel_alpha = TRUE,              
-                   Ncores = 2)                         
+                   parallel_alpha = FALSE)              
 
 ## ---- fig.show='hold', fig.height=4, fig.width=7, warning=FALSE---------------
 plot(res_rot)
@@ -76,7 +107,31 @@ res_merge <- merge_rotations(res, res_rot)
 ## ---- fig.show='hold', fig.height=4, fig.width=4, warning=FALSE---------------
 plot_criterion(res_merge)
 
-## ---- label="Fit_EM_rot2", warning=FALSE, message = FALSE---------------------
+## ---- label="Fit_EM_rot2", warning=FALSE, message = FALSE, eval = FALSE-------
+#  # An other rotation
+#  theta <- pi/3
+#  rot2 <- matrix(c(cos(theta), -sin(theta), sin(theta), cos(theta)),
+#                nrow = 2, ncol = 2)
+#  
+#  # Rotate data
+#  Yrot2 <- t(rot2) %*% monkeys$dat
+#  rownames(Yrot2) <- rownames(monkeys$dat)
+#  
+#  # PhyloEM on rotated data
+#  res_rot2 <- PhyloEM(phylo = monkeys$phy,
+#                     Y_data = Yrot2,
+#                     process = "scOU",
+#                     random.root = TRUE,
+#                     stationary.root = TRUE,
+#                     nbr_alpha = 2,           ## Note that this can also be different
+#                     K_max = 10,
+#                     parallel_alpha = TRUE,
+#                     Ncores = 2)
+#  
+#  # Merge
+#  res_merge2 <- merge_rotations(res, res_rot, res_rot2)
+
+## ----label="Fit_EM_rot2_int", echo=FALSE, warning=FALSE, message=FALSE--------
 # An other rotation
 theta <- pi/3
 rot2 <- matrix(c(cos(theta), -sin(theta), sin(theta), cos(theta)),
@@ -88,31 +143,39 @@ rownames(Yrot2) <- rownames(monkeys$dat)
 
 # PhyloEM on rotated data
 res_rot2 <- PhyloEM(phylo = monkeys$phy,
-                   Y_data = Yrot2,
-                   process = "scOU",                   
-                   random.root = TRUE,                 
-                   stationary.root = TRUE,
-                   nbr_alpha = 2,           ## Note that this can also be different
-                   K_max = 10,                        
-                   parallel_alpha = TRUE,            
-                   Ncores = 2)                        
-
+                    Y_data = Yrot2,
+                    process = "scOU",                   
+                    random.root = TRUE,                 
+                    stationary.root = TRUE,
+                    nbr_alpha = 2,           ## Note that this can also be different
+                    K_max = 10,                        
+                    parallel_alpha = FALSE)       
 # Merge
 res_merge2 <- merge_rotations(res, res_rot, res_rot2)
 
 ## ---- fig.show='hold', fig.height=4, fig.width=4, warning=FALSE---------------
 plot_criterion(res_merge2)
 
-## ---- label="Fit_EM_negative", warning=FALSE, message = FALSE-----------------
+## ---- label="Fit_EM_negative", warning=FALSE, message = FALSE, eval = FALSE----
+#  res_neg <- PhyloEM(phylo = monkeys$phy,
+#                     Y_data = monkeys$dat,
+#                     process = "scOU",
+#                     random.root = FALSE,      ## root needs to be fixed
+#                     K_max = 10,
+#                     parallel_alpha = TRUE,
+#                     Ncores = 2,
+#                     nbr_alpha = 4,            ## 2 negative, 2 positive (should be more)
+#                     allow_negative = TRUE)    ## allow negative alpha in the grid
+
+## ----label="Fit_EM_negative_int", echo=FALSE, warning=FALSE, message=FALSE----
 res_neg <- PhyloEM(phylo = monkeys$phy,
                    Y_data = monkeys$dat,
                    process = "scOU",
                    random.root = FALSE,      ## root needs to be fixed
                    K_max = 10,
-                   parallel_alpha = TRUE,
-                   Ncores = 2,
+                   parallel_alpha = FALSE,
                    nbr_alpha = 4,            ## 2 negative, 2 positive (should be more)
-                   allow_negative = TRUE)    ## allow negative alpha in the grid
+                   allow_negative = TRUE)    ## allow negative alpha in the grid      
 
 ## -----------------------------------------------------------------------------
 params_process(res_neg, K = 0)
